# $Header: /usr/custom/cvs/public/EasyPublisher/lib/python/Products/EasyLanguageService/Attic/rfc3066_language_codes.py,v 1.1.2.2 2002/08/12 08:24:46 johanc Exp $
#
# (c) 2002, Torped Strategi och Kommunikation AB.
# See License.txt for License information.
#
__version__='$Revision: 1.1.2.2 $'[11:-2]
__doc__ = """RFC-3066 Language Csodes

The rfc3066_language_codes module contains mappings between RFC-3066 
language codes to Language names.

Only ISO 639_1: 2-letter codes and combination of ISO 639: 2-letter codes
and ISO 3166-1 country codes are currently supported. 
This is what is supported by Internet Explorer and possibly other browsers.

The following dictionaries are defined:

iso_3166_1 (country codes)  ;   iso_3166_1 -> Country (plain text)
rfc_3066   (language codes) ;   rfc_3066 -> Language (plain text)
iso_639_1  (language codes) ;   iso_639_1 (2 letter codes) -> Language (plain text)
iso_639_1_sv ('')           ;   iso_639_1 (2 letter codes) -> Language (plain text, in Swedish)

Not defined in this file:

iso_639_2 (three letter codes)


"""

rfc_3066 = {
'aa':'Afar',
'ab':'Abkhazian',
'af':'Afrikaans',
'am':'Amharic',
'ar':'Arabic',
'ar-ae':'Arabic (U.A.E.)',
'ar-bh':'Arabic (Bahrain)',
'ar-dz':'Arabic (Algeria)',
'ar-eg':'Arabic (Egypt)',
'ar-iq':'Arabic (Iraq)',
'ar-jo':'Arabic (Jordan)',
'ar-kw':'Arabic (Kuwait)',
'ar-lb':'Arabic (Lebanon)',
'ar-ly':'Arabic (Libya)',
'ar-ma':'Arabic (Morocco)',
'ar-om':'Arabic (Oman)',
'ar-qa':'Arabic (Qatar)',
'ar-sa':'Arabic (Saudi Arabia)',
'ar-sy':'Arabic (Syria)',
'ar-tn':'Arabic (Tunisia)',
'ar-ye':'Arabic (Yemen)',
'as':'Assamese',
'ay':'Aymara',
'az':'Azerbaijani',
'ba':'Bashkir',
'be':'Belarusian',
'bg':'Bulgarian',
'bh':'Bihari',
'bi':'Bislama',
#'bn':'Bengali; Bangla',
'bn':'Bengali',
'bo':'Tibetan',
'br':'Breton',
'ca':'Catalan',
'co':'Corsican',
'cs':'Czech',
'cy':'Welsh',
'da':'Danish',
'de':'German',
'de-at':'German (Austria)',
'de-au':'German (Austria)',
'de-ch':'German (Switzerland)',
'de-de':'German (Germany)',
'de-li':'German (Liechtenstein)',
'de-lu':'German (Luxembourg)',
'dz':'Bhutani',
'el':'Greek',
'en':'English',
'en-au':'English (Australia)',
'en-bz':'English (Belize)',
'en-ca':'English (Canada)',
#'en-??':'English (Caribbean)',
'en-gb':'English (Great Britain)',
'en-ie':'English (Ireland)',
'en-jm':'English (Jamaica)',
'en-nz':'English (New Zealand)',
'en-tt':'English (Trinidad)',
'en-us':'English (United States)',
'en-za':'English (South Africa)',
'eo':'Esperanto',
'es':'Spanish',
'es-ar':'Spanish (Argentina)',
'es-bo':'Spanish (Bolivia)',
'es-cl':'Spanish (Chile)',
'es-co':'Spanish (Colombia)',
'es-cr':'Spanish (Costa Rica)',
'es-do':'Spanish (Dominican Republic)',
'es-ec':'Spanish (Ecuador)',
'es-es':'Spanish (Spain)',
'es-gt':'Spanish (Guatemala)',
'es-hn':'Spanish (Honduras)',
'es-mx':'Spanish (Mexico)',
'es-ni':'Spanish (Nicaragua)',
'es-pa':'Spanish (Panama)',
'es-pe':'Spanish (Peru)',
'es-pr':'Spanish (Puerto Rico)',
'es-py':'Spanish (Paraguay)',
'es-sv':'Spanish (El Salvador)',
'es-uy':'Spanish (Uruguay)',
'es-ve':'Spanish (Venezuela)',
'et':'Estonian',
'eu':'Basque',
'fa':'Farsi',
'fi':'Finnish',
'fj':'Fiji',
'fo':'Faeroese',
'fr':'French',
'fr-be':'French (Belgium)',
'fr-ca':'French (Canada)',
'fr-ch':'French (Switzerland)',
'fr-fr':'French (France)',
'fr-lu':'French (Luxembourg)',
'fy':'Frisian',
'ga':'Irish',
'gd':'Gaelic',
#'gd':'Gaelic (Scotland)',
'gd-ie':'Gaelic (Ireland)',
'gl':'Galician',
'gn':'Guarani',
'gu':'Gujarati',
'ha':'Hausa',
'he':'Hebrew',
'hi':'Hindi',
'hr':'Croatian',
'hu':'Hungarian',
'hy':'Armenian',
'ia':'Interlingua',
'id':'Indonesian',
'ie':'Interlingue',
'ik':'Inupiak',
'in':'Indonesian',
'is':'Icelandic',
'it':'Italian',
'it-ch':'Italian (Switzerland)',
'iu':'Inuktitut',
'ja':'Japanese',
'ji':'Yiddish',
'jw':'Javanese',
'ka':'Georgian',
'kk':'Kazakh',
'kl':'Greenlandic',
'km':'Cambodian',
'kn':'Kannada',
'ko':'Korean',
#'ko':'Korean (Johab)',
'ks':'Kashmiri',
'ku':'Kurdish',
'ky':'Kirghiz',
'la':'Latin',
'ln':'Lingala',
'lo':'Laothian',
'lt':'Lithuanian',
'lv':'Latvian',
'mg':'Malagasy',
'mi':'Maori',
'mk':'FYRO Macedonian',
'ml':'Malayalam',
'mn':'Mongolian',
'mo':'Moldavian',
'mr':'Marathi',
'ms':'Malay',
#'ms':'Malaysian',???
'mt':'Maltese',
'my':'Burmese',
'na':'Nauru',
'ne':'Nepali',
'nl':'Dutch',
'nl-be':'Dutch (Belgium)',
'no':'Norwegian',
#'no':'Norwegian (Nynorsk)',
'oc':'Occitan',
'om':'Oromo',
#'om':'(Afan) Oromo',
'or':'Oriya',
'pa':'Punjabi',
'pl':'Polish',
'ps':'Pashto',
#'ps':'Pashto, Pushto',
'pt':'Portuguese',
#'pt':'Portuguese (Portugal)',
'pt-br':'Portuguese (Brazil)',
'qu':'Quechua',
'rm':'Rhaeto-Romanic',
'rn':'Kirundi',
'ro':'Romanian',
'ro-mo':'Romanian (Moldavia)',
'ru':'Russian',
'ru-mo':'Russian (Moldavia)',
'rw':'Kinyarwanda',
'sa':'Sanskrit',
'sb':'Sorbian',
'sd':'Sindhi',
'sg':'Sangho',
'sh':'Serbo-Croatian',
'si':'Sinhalese',
'sk':'Slovak',
'sl':'Slovenian',
'sm':'Samoan',
'sn':'Shona',
'so':'Somali',
'sq':'Albanian',
'sr':'Serbian',
#'sr':'Serbian (Latin)',
'ss':'Siswati',
'st':'Sesotho',
'su':'Sundanese',
'sv':'Swedish',
'sv-fi':'Swedish (Finland)',
'sw':'Swahili',
'sx':'Sutu',
'sz':'Sami (Lappish)',
'ta':'Tamil',
'te':'Telugu',
'tg':'Tajik',
'th':'Thai',
'ti':'Tigrinya',
'tk':'Turkmen',
'tl':'Tagalog',
'tn':'Tswana',
'to':'Tonga',
'tr':'Turkish',
'ts':'Tsonga',
'tt':'Tatar',
'tw':'Twi',
'ug':'Uighur',
'uk':'Ukrainian',
'ur':'Urdu',
'uz':'Uzbek',
've':'Venda',
'vi':'Vietnamese',
'vo':'Volapuk',
'wo':'Wolof',
'xh':'Xhosa',
'yi':'Yiddish',
'yo':'Yoruba',
'za':'Zhuang',
'zh':'Chinese',
'zh-cn':'Chinese (PRC)',
'zh-hk':'Chinese (Hong Kong SAR)',
'zh-sg':'Chinese (Singapore)',
'zh-tw':'Chinese (Taiwan)',
'zu':'Zulu',
}

iso_3166_1={
'ad':'''Andorra''',
'ae':'''United Arab Emirates''',
'af':'''Afghanistan''',
'ag':'''Antigua and Barbuda''',
'ai':'''Anguilla''',
'al':'''Albania''',
'am':'''Armenia''',
'an':'''Netherlands Antilles''',
'ao':'''Angola''',
'aq':'''Antarctica''',
'ar':'''Argentina''',
'as':'''American Samoa''',
'at':'''Austria''',
'au':'''Australia''',
'aw':'''Aruba''',
'az':'''Azerbaijan''',
'ba':'''Bosnia and Herzegovina''',
'bb':'''Barbados''',
'bd':'''Bangladesh''',
'be':'''Belgium''',
'bf':'''Burkina Faso''',
'bg':'''Bulgaria''',
'bh':'''Bahrain''',
'bi':'''Burundi''',
'bj':'''Benin''',
'bm':'''Bermuda''',
'bn':'''Brunei Darussalam''',
'bo':'''Bolivia''',
'br':'''Brazil''',
'bs':'''Bahamas''',
'bt':'''Bhutan''',
'bv':'''Bouvet Island''',
'bw':'''Botswana''',
'by':'''Belarus''',
'bz':'''Belize''',
'ca':'''Canada''',
'cc':'''Cocos (Keeling) Islands''',
'cd':'''Congo, The Democratic Republic of the''',
'cf':'''Central African Republic''',
'cg':'''Congo''',
'ch':'''Switzerland''',
'ci':'''Cte D'ivoire''',
'ck':'''Cook Islands''',
'cl':'''Chile''',
'cm':'''Cameroon''',
'cn':'''China''',
'co':'''Colombia''',
'cr':'''Costa Rica''',
'cu':'''Cuba''',
'cv':'''Cape Verde''',
'cx':'''Christmas Island''',
'cy':'''Cyprus''',
'cz':'''Czech Republic''',
'de':'''Germany''',
'dj':'''Djibouti''',
'dk':'''Denmark''',
'dm':'''Dominica''',
'do':'''Dominican Republic''',
'dz':'''Algeria''',
'ec':'''Ecuador''',
'ee':'''Estonia''',
'eg':'''Egypt''',
'eh':'''Western Sahara''',
'er':'''Eritrea''',
'es':'''Spain''',
'et':'''Ethiopia''',
'fi':'''Finland''',
'fj':'''Fiji''',
'fk':'''Falkland Islands (Malvinas)''',
'fm':'''Micronesia, Federated States of''',
'fo':'''Faroe Islands''',
'fr':'''France''',
'ga':'''Gabon''',
'gb':'''United Kingdom''',
'gd':'''Grenada''',
'ge':'''Georgia''',
'gf':'''French Guiana''',
'gh':'''Ghana''',
'gi':'''Gibraltar''',
'gl':'''Greenland''',
'gm':'''Gambia''',
'gn':'''Guinea''',
'gp':'''Guadeloupe''',
'gq':'''Equatorial Guinea''',
'gr':'''Greece''',
'gs':'''South Georgia and the South Sandwich Islands''',
'gt':'''Guatemala''',
'gu':'''Guam''',
'gw':'''Guinea-bissau''',
'gy':'''Guyana''',
'hk':'''Hong Kong''',
'hm':'''Heard Island and Mcdonald Islands''',
'hn':'''Honduras''',
'hr':'''Croatia''',
'ht':'''Haiti''',
'hu':'''Hungary''',
'id':'''Indonesia''',
'ie':'''Ireland''',
'il':'''Israel''',
'in':'''India''',
'io':'''British Indian Ocean Territory''',
'iq':'''Iraq''',
'ir':'''Iran, Islamic Republic of''',
'is':'''Iceland''',
'it':'''Italy''',
'jm':'''Jamaica''',
'jo':'''Jordan''',
'jp':'''Japan''',
'ke':'''Kenya''',
'kg':'''Kyrgyzstan''',
'kh':'''Cambodia''',
'ki':'''Kiribati''',
'km':'''Comoros''',
'kn':'''Saint Kitts and Nevis''',
'kp':'''Korea, Democratic People's Republic of''',
'kr':'''Korea, Republic of''',
'kw':'''Kuwait''',
'ky':'''Cayman Islands''',
'kz':'''Kazakstan''',
'la':'''Lao Peoples Democratic Republic''',
'lb':'''Lebanon''',
'lc':'''Saint Lucia''',
'li':'''Liechtenstein''',
'lk':'''Sri Lanka''',
'lr':'''Liberia''',
'ls':'''Lesotho''',
'lt':'''Lithuania''',
'lu':'''Luxembourg''',
'lv':'''Latvia''',
'ly':'''Libyan Arab Jamahiriya''',
'ma':'''Morocco''',
'mc':'''Monaco''',
'md':'''Moldova, Republic of''',
'mg':'''Madagascar''',
'mh':'''Marshall Islands''',
'mk':'''Macedonia, The Former Yugoslav Republic of''',
'ml':'''Mali''',
'mm':'''Myanmar''',
'mn':'''Mongolia''',
'mo':'''Macau''',
'mp':'''Northern Mariana Islands''',
'mq':'''Martinique''',
'mr':'''Mauritania''',
'ms':'''Montserrat''',
'mt':'''Malta''',
'mu':'''Mauritius''',
'mv':'''Maldives''',
'mw':'''Malawi''',
'mx':'''Mexico''',
'my':'''Malaysia''',
'mz':'''Mozambique''',
'na':'''Namibia''',
'nc':'''New Caledonia''',
'ne':'''Niger''',
'nf':'''Norfolk Island''',
'ng':'''Nigeria''',
'ni':'''Nicaragua''',
'nl':'''Netherlands''',
'no':'''Norway''',
'np':'''Nepal''',
'nr':'''Nauru''',
'nu':'''Niue''',
'nz':'''New Zealand''',
'om':'''Oman''',
'pa':'''Panama''',
'pe':'''Peru''',
'pf':'''French Polynesia''',
'pg':'''Papua New Guinea''',
'ph':'''Philippines''',
'pk':'''Pakistan''',
'pl':'''Poland''',
'pm':'''Saint Pierre and Miquelon''',
'pn':'''Pitcairn''',
'pr':'''Puerto Rico''',
'ps':'''Palestinian Territory, Occupied''',
'pt':'''Portugal''',
'pw':'''Palau''',
'py':'''Paraguay''',
'qa':'''Qatar''',
're':'''R'union''',
'ro':'''Romania''',
'ru':'''Russian Federation''',
'rw':'''Rwanda''',
'sa':'''Saudi Arabia''',
'sb':'''Solomon Islands''',
'sc':'''Seychelles''',
'sd':'''Sudan''',
'se':'''Sweden''',
'sg':'''Singapore''',
'sh':'''Saint Helena''',
'si':'''Slovenia''',
'sj':'''Svalbard and Jan Mayen''',
'sk':'''Slovakia''',
'sl':'''Sierra Leone''',
'sm':'''San Marino''',
'sn':'''Senegal''',
'so':'''Somalia''',
'sr':'''Suriname''',
'st':'''Sao Tome and Principe''',
'sv':'''El Salvador''',
'sy':'''Syrian Arab Republic''',
'sz':'''Swaziland''',
'tc':'''Turks and Caicos Islands''',
'td':'''Chad''',
'tf':'''French Southern Territories''',
'tg':'''Togo''',
'th':'''Thailand''',
'tj':'''Tajikistan''',
'tk':'''Tokelau''',
'tm':'''Turkmenistan''',
'tn':'''Tunisia''',
'to':'''Tonga''',
'tp':'''East Timor''',
'tr':'''Turkey''',
'tt':'''Trinidad and Tobago''',
'tv':'''Tuvalu''',
'tw':'''Taiwan, Province of China''',
'tz':'''Tanzania, United Republic of''',
'ua':'''Ukraine''',
'ug':'''Uganda''',
'um':'''United States Minor Outlying Islands''',
'us':'''United States''',
'uy':'''Uruguay''',
'uz':'''Uzbekistan''',
'va':'''Holy See (vatican City State)''',
'vc':'''Saint Vincent and the Grenadines''',
've':'''Venezuela''',
'vg':'''Virgin Islands, British''',
'vi':'''Virgin Islands, U.s.''',
'vn':'''Viet Nam''',
'vu':'''Vanuatu''',
'wf':'''Wallis and Futuna''',
'ws':'''Samoa''',
'ye':'''Yemen''',
'yt':'''Mayotte''',
'yu':'''Yugoslavia''',
'za':'''South Africa''',
'zm':'''Zambia''',
'zw':'''Zimbabwe''',
}

iso_639_1 = {
'aa':'Afar',  
'ab':'Abkhazian',  
'af':'Afrikaans',  
'am':'Amharic',  
'ar':'Arabic',  
'as':'Assamese',  
'ay':'Aymara',  
'az':'Azerbaijani',  
'ba':'Bashkir',  
'be':'Byelorussian (Belarussian)',
'bg':'Bulgarian',  
'bh':'Bihari',  
'bi':'Bislama',  
'bn':'Bengali',  
'bo':'Tibetan',  
'br':'Breton',  
'ca':'Catalan',  
'co':'Corsican',  
'cs':'Czech',  
'cy':'Welsh',  
'da':'Danish',  
'de':'German',  
'dz':'Bhutani',  
'el':'Greek',  
'en':'English',  
'eo':'Esperanto',  
'es':'Spanish',  
'et':'Estonian',  
'eu':'Basque',  
'fa':'Persian',  
'fi':'Finnish',  
'fj':'Fiji',  
'fo':'Faroese',  
'fr':'French',  
'fy':'Frisian',  
'ga':'Irish (Irish Gaelic)',
'gd':'Scots Gaelic (Scottish Gaelic)', 
'gl':'Galician',  
'gn':'Guarani',  
'gu':'Gujarati',  
'gv':'Manx Gaelic',   
'ha':'Hausa',  
'he':'Hebrew',
'hi':'Hindi',  
'hr':'Croatian',  
'hu':'Hungarian',  
'hy':'Armenian',  
'ia':'Interlingua',  
'id':'Indonesian',  
'ie':'Interlingue',  
'ik':'Inupiak',  
'is':'Icelandic',  
'it':'Italian',  
'iu':'Inuktitut',  
'ja':'Japanese',  
'jw':'Javanese',  
'ka':'Georgian',  
'kk':'Kazakh',  
'kl':'Greenlandic',  
'km':'Cambodian',  
'kn':'Kannada',  
'ko':'Korean',  
'ks':'Kashmiri',  
'ku':'Kurdish',  
'kw':'Cornish',  
'ky':'Kirghiz',  
'la':'Latin',  
'lb':'Luxemburgish',  
'ln':'Lingala',  
'lo':'Laotian',  
'lt':'Lithuanian',  
'lv':'Latvian Lettish',   
'mg':'Malagasy',  
'mi':'Maori',  
'mk':'Macedonian',  
'ml':'Malayalam',  
'mn':'Mongolian',  
'mo':'Moldavian',  
'mr':'Marathi',  
'ms':'Malay',  
'mt':'Maltese',  
'my':'Burmese',  
'na':'Nauru',  
'ne':'Nepali',  
'nl':'Dutch',  
'no':'Norwegian',  
'oc':'Occitan',  
'om':'Oromo',  
'or':'Oriya',  
'pa':'Punjabi',  
'pl':'Polish',  
'ps':'Pashto',  
'pt':'Portuguese',  
'qu':'Quechua',  
'rm':'Rhaeto-Romance',  
'rn':'Kirundi',  
'ro':'Romanian',  
'ru':'Russian',  
'rw':'Kiyarwanda',  
'sa':'Sanskrit',  
'sd':'Sindhi',  
'se':'Northern Smi',  
'sg':'Sangho',  
'sh':'Serbo-Croatian',
'si':'Singhalese',  
'sk':'Slovak',  
'sl':'Slovenian',  
'sm':'Samoan',  
'sn':'Shona',  
'so':'Somali',  
'sq':'Albanian',  
'sr':'Serbian',  
'ss':'Siswati',  
'st':'Sesotho',  
'su':'Sudanese',  
'sv':'Swedish',  
'sw':'Swahili',  
'ta':'Tamil',  
'te':'Telugu',  
'tg':'Tajik',  
'th':'Thai',  
'ti':'Tigrinya',  
'tk':'Turkmen',  
'tl':'Tagalog',  
'tn':'Setswana',  
'to':'Tonga',  
'tr':'Turkish',  
'ts':'Tsonga',  
'tt':'Tatar',  
'tw':'Twi',  
'ug':'Uigur',  
'uk':'Ukrainian',  
'ur':'Urdu',  
'uz':'Uzbek',  
'vi':'Vietnamese',  
'vo':'Volapk',
'wo':'Wolof',  
'xh':'Xhosa',  
'yi':'Yiddish',  
'yo':'Yorouba',  
'za':'Zhuang',  
'zh':'Chinese',  
'zu':'Zulu', 
}


iso_639_1_sv = {
'aa':'Afariska',  
'ab':'Abchasiska',  
'af':'Afrikaans',  
'am':'Amhariska',  
'ar':'Arabiska',  
'as':'Assamesiska',  
'ay':'Aymariska',  
'az':'Azerbajdjanska',  
'ba':'Bashkiriska',  
'be':'Vitryska',  
'bg':'Bulgariska',  
'bh':'Bihari',  
'bi':'Bislamiska',  
'bn':'Bengali',  
'bo':'Tibetanska',  
'br':'Bretonska',  
'ca':'Katalanska',  
'co':'Korsikanska',  
'cs':'Tjeckiska',  
'cy':'Walesiska',  
'da':'Danska',  
'de':'Tyska',  
'dz':'Bhutanska',  
'el':'Grekiska',  
'en':'Engelska',  
'eo':'Esperanto',  
'es':'Spanska',  
'et':'Estniska',  
'eu':'Baskiska',  
'fa':'Persiska',  
'fi':'Finska',  
'fj':'Fiji',  
'fo':'Friska',
'fr':'Franska',  
'fy':'Frisiska',  
'ga':'Iriska',  
'gd':'Skotsk gaeliska',
'gl':'Galiciska',  
'gn':'Guarani',  
'gu':'Gujarati',  
'ha':'Hausa',  
'he':'Hebreiska',  
'hi':'Hindi',  
'hr':'Kroatiska',  
'hu':'Ungerska',  
'hy':'Armeniska',  
'ia':'Interlingua',  
'id':'Indonesiska',  
'ie':'Interlingue',  
'ik':'Inupiak',  
'is':'Islndska',
'it':'Italienska',  
'ja':'Japanska',  
'jw':'Javanesiska',  
'ka':'Georgiska',  
'kk':'Kazakiska',  
'kl':'Grnlndska',
'km':'Kambodjanska',  
'kn':'Kannada',  
'ko':'Koreanska',  
'ks':'Kashmiri',  
'ku':'Kurdiska',  
'ky':'Kirgisiska',  
'la':'Latin',  
'ln':'Lingala',  
'lo':'Laotiska',  
'lt':'Litauiska',  
'lv':'Lettiska',  
'mg':'Malagassiska',  
'mi':'Maori',  
'mk':'Makedonska',  
'ml':'Malayalam',  
'mn':'Mongoliska',  
'mo':'Moldaviska',  
'mr':'Marathi',  
'ms':'Malajiska',  
'mt':'Maltesiska',  
'my':'Burmanska',  
'na':'Nauriska',  
'ne':'Nepalesiska',  
'nl':'Hollndska',
'no':'Norska',  
'oc':'Occitanska',  
'om':'Oromo',  
'or':'Oriya',  
'pa':'Punjabi',  
'pl':'Polska',  
'ps':'Pashto',  
'pt':'Portugisiska',  
'qu':'Quechua',  
'rm':'Rtoromanska',
'rn':'Kirundi',  
'ro':'Rumnska',  
'ru':'Ryska',  
'rw':'Kiyarwanda',  
'sa':'Sanskrit',  
'sd':'Sindhi',  
'sg':'Sangho',  
'sh':'Serbokroatiska',  
'si':'Singalesiska',  
'sk':'Slovakiska',  
'sl':'Slovenska',  
'sm':'Samoanska',  
'sn':'Shona',  
'so':'Somaliska',  
'sq':'Albanska',  
'sr':'Serbiska',  
'ss':'Siswati',  
'st':'Sesotho',  
'su':'Sudanesiska',  
'sv':'Svenska',  
'sw':'Swahili',  
'ta':'Tamil',  
'te':'Telugu',  
'tg':'Tajikiska',  
'th':'Thailndska',  
'ti':'Tigrinya',  
'tk':'Turkmeniska',  
'tl':'Tagalog',  
'tn':'Setswana',  
'to':'Tonga',  
'tr':'Turkiska',  
'ts':'Tsonga',  
'tt':'Tatariska',  
'tw':'Twi',  
'uk':'Ukrainska',  
'ur':'Urdu',  
'uz':'Uzbekiska',  
'vi':'Vietnamesiska',  
'vo':'Volapk',  
'wo':'Wolof',  
'xh':'Xhosa',  
'yi':'Jiddisch',
'ji': 'Jiddisch',
'yo':'Yoruba',  
'zh':'Kinesiska',  
'zu':'Zulu',  
}

geographical_regions = {
'europe':'Europe',
'asia':'Asia',
'america':'America',
'south_america':'South America',
'north_america':'North America',
'central_america':'Central America',
'gat':'GAT',
'africa':'Africa',
'eu':'European Union',
'nato':'Nato',
'europe':'Europe',
'ussr':'USSR (former)',
'middle_east':'Middle East',
'un':'United Nations',
}

geographical_regions_map = {
'europe':('se','de'),
'asia':(),
'america':('us','ca'),
'south_america':(),
'north_america':('us','ca'),
'gat':('us','ca'),
'central_america':(),
'africa':(),
'eu':(),
'nato':(),
'europe':(),
'ussr':(),
'middle_east':(),
'un':(),
}

nordic=('sv','da','no','fi','is')
central_europe=('de','fr','en','es')
east_europe=()
south_europe=()
nordic=('sv','da','no','fi','is')
baltic=('lt','lv','et')
north_america=('us','ca')
eu = ()
africa=()
nato=()

geographical_regions_language_map = {
'europe':nordic+central_europe+east_europe+south_europe,
'central_europe':central_europe,
'east_europe':east_europe,
'south_europe':south_europe,
'nordic':nordic,
'baltic':baltic,
#'asia':(),
'america':('us','ca'),
#'south_america':(),
'north_america':north_america,
#'gat':north_america+('mx',),
#'central_america':(),
#'africa':africa,
'eu':eu,
#'nato':nato,
#'ussr':(),
#'middle_east':(),
#'un':(),
}

def invertDict(dict):
    d={}
    for k,v in dict.items():
        d[v]=k
    return d
